# ResumePolicy

Resume methods. Specify a way to resume a subscription. See [Resume Date](https://knowledgecenter.zuora.com/BC_Subscription_Management/Subscriptions/Resume_a_Subscription#Resume_Date) for more information.  If `SuspendDate` is specfied, the resumption will take place on the same day as the suspension.  

## Enum

* `TODAY` (value: `'Today'`)

* `FIXEDPERIODSFROMSUSPENDDATE` (value: `'FixedPeriodsFromSuspendDate'`)

* `FIXEDPERIODSFROMTODAY` (value: `'FixedPeriodsFromToday'`)

* `SPECIFICDATE` (value: `'SpecificDate'`)

* `SUSPENDDATE` (value: `'SuspendDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


